summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorlhauch <lhauch@6f19259b-4bc3-4df7-8a09-765794883524>2006-07-29 04:39:01 +0000
committerlhauch <lhauch@6f19259b-4bc3-4df7-8a09-765794883524>2006-07-29 04:39:01 +0000
commit9e857952dbebe1fcadb4efeee8ca338c1123bd13 (patch)
tree5053166d5df9c64706d9c9fdfcfd4a971a5ec774
parent64e0af09a61f032225684c5c75bdedfb0aa99ba0 (diff)
downloadedk2-platforms-9e857952dbebe1fcadb4efeee8ca338c1123bd13.tar.xz
Added some additional comments in the files, as well as fixed some of them.
git-svn-id: https://edk2.svn.sourceforge.net/svnroot/edk2/trunk/edk2@1149 6f19259b-4bc3-4df7-8a09-765794883524
-rw-r--r--Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/BootModesDlg.java9
-rw-r--r--Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/DataHubsDlg.java5
-rw-r--r--Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/EventsDlg.java24
-rw-r--r--Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/ExternsDlg.java11
-rw-r--r--Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/HiiPackagesDlg.java2
-rw-r--r--Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/HobsDlg.java6
-rw-r--r--Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/LibraryClassDefsDlg.java4
-rw-r--r--Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/PCDsDlg.java11
-rw-r--r--Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/PackageDepDlg.java12
-rw-r--r--Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/PpisDlg.java5
-rw-r--r--Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/SystemTablesDlg.java5
-rw-r--r--Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/VariablesDlg.java15
12 files changed, 55 insertions, 54 deletions
diff --git a/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/BootModesDlg.java b/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/BootModesDlg.java
index 937b8b6361..2e637eb1ee 100644
--- a/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/BootModesDlg.java
+++ b/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/BootModesDlg.java
@@ -42,10 +42,9 @@ import org.tianocore.frameworkwizard.common.ui.StarLabel;
import org.tianocore.frameworkwizard.module.Identifications.BootModes.BootModesIdentification;
/**
- * The class is used to create, update BootModes of MSA/MBD file It extends
- * IDialog
- *
- *
+ * The class is used to create, update BootModes of MSA/MBD file
+ *
+ * It extends IDialog
*
*/
public class BootModesDlg extends IDialog {
@@ -59,7 +58,7 @@ public class BootModesDlg extends IDialog {
// Define class members
//
private JPanel jContentPane = null;
-private JLabel jLabelTest = null;
+
private JLabel jLabelBootModeName = null;
private JComboBox jComboBoxBootModeName = null;
diff --git a/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/DataHubsDlg.java b/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/DataHubsDlg.java
index b5238d9707..d22e80ceb7 100644
--- a/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/DataHubsDlg.java
+++ b/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/DataHubsDlg.java
@@ -42,10 +42,9 @@ import org.tianocore.frameworkwizard.common.ui.StarLabel;
import org.tianocore.frameworkwizard.module.Identifications.DataHubs.DataHubsIdentification;
/**
- * The class is used to create, update DataHub of MSA/MBD file It extends
- * IInternalFrame
- *
+ * The class is used to create, update DataHub of the MSA file
*
+ * It extends IDialog
*
*/
public class DataHubsDlg extends IDialog {
diff --git a/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/EventsDlg.java b/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/EventsDlg.java
index 624fae71df..71af9edaf9 100644
--- a/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/EventsDlg.java
+++ b/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/EventsDlg.java
@@ -121,9 +121,9 @@ public class EventsDlg extends IDialog {
jComboBoxEventsType.setBounds(new java.awt.Rectangle(168, 12, 320, 20));
jComboBoxEventsType.setPreferredSize(new java.awt.Dimension(320, 20));
jComboBoxEventsType
- .setToolTipText("<html>Select CreateEvents if the Module has an event that is waiting to be signaled.<br>"
- + "Select SignalEvents if the Module will signal all events in an event group.<br>"
- + "NOTE: Signal events are named by GUID.</html>");
+ .setToolTipText("<html>Select CreateEvents if the Module has an event that is waiting to be signaled.<br>"
+ + "Select SignalEvents if the Module will signal all events in an event group.<br>"
+ + "NOTE: Signal events are named by GUID.</html>");
}
return jComboBoxEventsType;
}
@@ -172,15 +172,15 @@ public class EventsDlg extends IDialog {
jComboBoxUsage.setBounds(new java.awt.Rectangle(168, 87, 320, 20));
jComboBoxUsage.setPreferredSize(new java.awt.Dimension(320, 20));
jComboBoxUsage
- .setToolTipText("<html><table>"
- + "<tr><td colspan=2 align=center><b>Create Events</b></td></tr>"
- + "<tr><td>ALWAYS_CONSUMED</td><td>Module registers a notification function and REQUIRES that it be<br>"
- + "executed for the module to fully function.</td></tr>"
- + "<tr><td>SOMETIMES_CONSUMED</td><td>Module registers a notification function and calls the function<br>"
- + "when it is signaled</td></tr><tr><td colspan=2 align=center><b>Signal Events</b></td></tr>"
- + "<tr><td>ALWAYS_PRODUCED</td><td>Module will Always signal the event</td></tr>"
- + "<tr><td>SOMETIMES_PRODUCED</td><td>Module will sometimes signal the event</td></tr>"
- + "</table></html>");
+ .setToolTipText("<html><table>"
+ + "<tr><td colspan=2 align=center><b>Create Events</b></td></tr>"
+ + "<tr><td>ALWAYS_CONSUMED</td><td>Module registers a notification function and REQUIRES that it be<br>"
+ + "executed for the module to fully function.</td></tr>"
+ + "<tr><td>SOMETIMES_CONSUMED</td><td>Module registers a notification function and calls the function<br>"
+ + "when it is signaled</td></tr><tr><td colspan=2 align=center><b>Signal Events</b></td></tr>"
+ + "<tr><td>ALWAYS_PRODUCED</td><td>Module will Always signal the event</td></tr>"
+ + "<tr><td>SOMETIMES_PRODUCED</td><td>Module will sometimes signal the event</td></tr>"
+ + "</table></html>");
}
return jComboBoxUsage;
}
diff --git a/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/ExternsDlg.java b/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/ExternsDlg.java
index 80ff5a2367..68bfec2cc1 100644
--- a/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/ExternsDlg.java
+++ b/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/ExternsDlg.java
@@ -37,12 +37,11 @@ import org.tianocore.frameworkwizard.common.ui.IFrame;
import org.tianocore.frameworkwizard.module.Identifications.Externs.ExternsIdentification;
/**
- The class is used to create, update Externs section of the MSA file
- It extends IDialog
-
-
-
- **/
+ * The class is used to create, update Externs section of the MSA file
+ *
+ * It extends IDialog
+ *
+ */
public class ExternsDlg extends IDialog implements ItemListener {
///
diff --git a/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/HiiPackagesDlg.java b/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/HiiPackagesDlg.java
index a3c4b96fdc..cec910d091 100644
--- a/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/HiiPackagesDlg.java
+++ b/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/HiiPackagesDlg.java
@@ -1,6 +1,6 @@
/** @file
- The file is used to create, update Hii Packages section of the MSA file
+ The file is used to create, update Hii Packages section of the MSA file
Copyright (c) 2006, Intel Corporation
All rights reserved. This program and the accompanying materials
diff --git a/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/HobsDlg.java b/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/HobsDlg.java
index d46958be1b..bb28db42e7 100644
--- a/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/HobsDlg.java
+++ b/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/HobsDlg.java
@@ -1,6 +1,6 @@
/** @file
- The file is used to create, update Hob of MSA/MBD file
+ The file is used to create, update Hob section of the MSA file
Copyright (c) 2006, Intel Corporation
All rights reserved. This program and the accompanying materials
@@ -38,7 +38,9 @@ import org.tianocore.frameworkwizard.module.Identifications.Hobs.HobsIdentificat
import org.tianocore.frameworkwizard.workspace.WorkspaceTools;
/**
- * The class is used to create, update Hob of the MSA file It extends JDialog
+ * The class is used to create, update Hob of the MSA file
+ *
+ * It extends IDialog
*
*/
public class HobsDlg extends IDialog {
diff --git a/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/LibraryClassDefsDlg.java b/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/LibraryClassDefsDlg.java
index 8b5dfd980b..8ac87003d3 100644
--- a/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/LibraryClassDefsDlg.java
+++ b/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/LibraryClassDefsDlg.java
@@ -39,11 +39,11 @@ import org.tianocore.frameworkwizard.module.Identifications.LibraryClass.Library
import org.tianocore.frameworkwizard.workspace.WorkspaceTools;
/**
- * The class is used to create, update Library Class Definition of MSA/MBD file
+ * The class is used to create, update Library Class Definition section of the MSA file
*
* It extends IDialog
*
- **/
+ */
public class LibraryClassDefsDlg extends IDialog {
///
diff --git a/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/PackageDepDlg.java b/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/PackageDepDlg.java
index ec122e6c97..2c7a355cc3 100644
--- a/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/PackageDepDlg.java
+++ b/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/PackageDepDlg.java
@@ -40,7 +40,7 @@ import org.tianocore.frameworkwizard.workspace.WorkspaceTools;
/**
* The class is used to create, update Package Dependencies section of the MSA file
*
- * It extends * IDialog
+ * It extends IDialog
*
*/
public class PackageDepDlg extends IDialog implements ItemListener {
@@ -134,11 +134,11 @@ public class PackageDepDlg extends IDialog implements ItemListener {
jTextFieldPackageVersion.setBounds(new java.awt.Rectangle(168, 37, 320, 20));
jTextFieldPackageVersion.setPreferredSize(new java.awt.Dimension(320, 20));
jTextFieldPackageVersion
- .setToolTipText("<html>If this module depends on a specific version of a package, <br>"
- + "enter the package version here. <br>"
- + "If the module can use the latest version <br>"
- + "that does not break backward compatibility, <br>"
- + "leave this field blank</html>");
+ .setToolTipText("<html>If this module depends on a specific version of a package, <br>"
+ + "enter the package version here. <br>"
+ + "If the module can use the latest version <br>"
+ + "that does not break backward compatibility, <br>"
+ + "leave this field blank</html>");
}
return jTextFieldPackageVersion;
}
diff --git a/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/PpisDlg.java b/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/PpisDlg.java
index 2a2d2d399f..5c1fb9826b 100644
--- a/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/PpisDlg.java
+++ b/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/PpisDlg.java
@@ -40,8 +40,9 @@ import org.tianocore.frameworkwizard.module.Identifications.Ppis.PpisIdentificat
import org.tianocore.frameworkwizard.workspace.WorkspaceTools;
/**
- * The class is used to create, update Ppi of MSA/MBD file It extends
- * IInternalFrame
+ * The class is used to create, update Ppi section of the MSA file
+ *
+ * It extends IDialog
*
*/
public class PpisDlg extends IDialog implements ItemListener {
diff --git a/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/SystemTablesDlg.java b/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/SystemTablesDlg.java
index 8919552e7f..d9ebc0f187 100644
--- a/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/SystemTablesDlg.java
+++ b/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/SystemTablesDlg.java
@@ -39,10 +39,9 @@ import org.tianocore.frameworkwizard.module.Identifications.SystemTables.SystemT
import org.tianocore.frameworkwizard.workspace.WorkspaceTools;
/**
- * The class is used to create, update SystemTable of MSA/MBD file
- * It extends IDialog
- *
+ * The class is used to create, update SystemTables section of the MSA file
*
+ * It extends IDialog
*
*/
public class SystemTablesDlg extends IDialog {
diff --git a/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/VariablesDlg.java b/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/VariablesDlg.java
index ca8a5839fe..014e8a7220 100644
--- a/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/VariablesDlg.java
+++ b/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/VariablesDlg.java
@@ -39,7 +39,8 @@ import org.tianocore.frameworkwizard.module.Identifications.Variables.VariablesI
import org.tianocore.frameworkwizard.workspace.WorkspaceTools;
/**
- * The class is used to create, update Variables section of the MSA file
+ * The class is used to create, update Variables section of the MSA file
+ *
* It extends IDialog
*
*/
@@ -132,12 +133,12 @@ public class VariablesDlg extends IDialog {
jComboBoxUsage.setBounds(new java.awt.Rectangle(168, 62, 320, 20));
jComboBoxUsage.setPreferredSize(new java.awt.Dimension(320, 20));
jComboBoxUsage
- .setToolTipText("<html><table>"
- + "<tr><td>ALWAYS_CONSUMED</td><td>The module requires the variable entry to be set</td></tr>"
- + "<tr><td>SOMETIMES_CONSUMED</td><td>The module will use the variable entry if it is set.</td></tr>"
- + "<tr><td>ALWAYS_PRODUCED</td><td>The module will always write the variable.</td></tr>"
- + "<tr><td>SOMETIMES_PRODUCED</td><td>The module will sometimes write the variable.</td></tr>"
- + "</table></html>");
+ .setToolTipText("<html><table>"
+ + "<tr><td>ALWAYS_CONSUMED</td><td>The module requires the variable entry to be set</td></tr>"
+ + "<tr><td>SOMETIMES_CONSUMED</td><td>The module will use the variable entry if it is set.</td></tr>"
+ + "<tr><td>ALWAYS_PRODUCED</td><td>The module will always write the variable.</td></tr>"
+ + "<tr><td>SOMETIMES_PRODUCED</td><td>The module will sometimes write the variable.</td></tr>"
+ + "</table></html>");
}
return jComboBoxUsage;
}
diff --git a/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/PCDsDlg.java b/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/PCDsDlg.java
index 9e0f120a19..c22f1f03c5 100644
--- a/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/PCDsDlg.java
+++ b/Tools/Source/FrameworkWizard/src/org/tianocore/frameworkwizard/module/ui/dialog/PCDsDlg.java
@@ -1,6 +1,6 @@
/** @file
- The file is used to create, update PCD of MSA/MBD file
+ The file is used to create, update PcdCode section of the MSA file
Copyright (c) 2006, Intel Corporation
All rights reserved. This program and the accompanying materials
@@ -41,8 +41,9 @@ import org.tianocore.frameworkwizard.module.Identifications.PcdCoded.PcdVector;
import org.tianocore.frameworkwizard.workspace.WorkspaceTools;
/**
* The class is used to create, update PCD of MSA/MBD file It extends
* IInternalFrame
*
*/
public class PCDsDlg extends IDialog implements ItemListener {
@@ -98,7 +99,7 @@ public class PCDsDlg extends IDialog implements ItemListener {
private JButton jButtonCancel = null;
private JScrollPane jScrollPaneHelpText = null;
-
+
private JLabel jLabelUsage = null;
private JComboBox jComboBoxUsage = null;
@@ -107,7 +108,7 @@ public class PCDsDlg extends IDialog implements ItemListener {
// Not used by UI
//
private PcdCodedIdentification id = null;
-
+
private EnumerationData ed = new EnumerationData();
private WorkspaceTools wt = new WorkspaceTools();
@@ -41,8 +41,9 @@ import org.tianocore.frameworkwizard.module.Identifications.PcdCoded.PcdVector;
import org.tianocore.frameworkwizard.workspace.WorkspaceTools;
/**
- * The class is used to create, update PCD of MSA/MBD file It extends
- * IInternalFrame
+ * The class is used to create, update PcdCoded section of the MSA file
+ *
+ * It extends IDialog
*
*/